@@ -88,6 +88,7 @@ def test_server(loop):
         await server.listen(8881)
         assert server.port == 8881
         assert server.address == ("tcp://%s:8881" % get_ip())
+        await server
 
         for addr in ("127.0.0.1:8881", "tcp://127.0.0.1:8881", server.address):
             comm = await connect(addr)
@@ -230,12 +231,10 @@ async def test_server_listen():
 
     sec = tls_security()
     async with listen_on(
-        Server, "tls://", listen_args=sec.get_listen_args("scheduler")
+        Server, "tls://", **sec.get_listen_args("scheduler")
     ) as server:
         assert server.address.startswith("tls://")
-        await assert_can_connect(
-            server.address, connection_args=sec.get_connection_args("client")
-        )
+        await assert_can_connect(server.address, **sec.get_connection_args("client"))
 
     # InProc
 
@@ -253,9 +252,9 @@ async def test_server_listen():
         await assert_cannot_connect(inproc_addr2)
 
 
-async def check_rpc(listen_addr, rpc_addr=None, listen_args=None, connection_args=None):
+async def check_rpc(listen_addr, rpc_addr=None, listen_args={}, connection_args={}):
     server = Server({"ping": pingpong})
-    await server.listen(listen_addr, listen_args=listen_args)
+    await server.listen(listen_addr, **listen_args)
     if rpc_addr is None:
         rpc_addr = server.address
 
@@ -603,7 +602,7 @@ async def test_connection_pool_tls():
 
     servers = [Server({"ping": ping}) for i in range(10)]
     for server in servers:
-        await server.listen("tls://", listen_args=listen_args)
+        await server.listen("tls://", **listen_args)
 
     rpc = await ConnectionPool(limit=5, connection_args=connection_args)
 
@@ -734,7 +733,7 @@ def test_rpc_serialization(loop):
 
 
 @gen_cluster()
-def test_thread_id(s, a, b):
+async def test_thread_id(s, a, b):
     assert s.thread_id == a.thread_id == b.thread_id == threading.get_ident()
 
 
@@ -781,4 +780,4 @@ async def test_connection_pool_detects_remote_close():
     # check connection pool invariants hold even after it detects a closed connection
     # while creating conn2:
     p._validate()
-    p.close()
+    await p.close()
